@@ -284,7 +284,11 @@ function NodeStandby($num)
 function conStr($num, $mode = NULL)
 {
     // check user info
-    if ($mode == 'stream' && paramExists('sr_check_user')) {
+    if ($mode == 'login') {
+        $user     = $_SESSION[SESSION_LOGIN_USER];
+        $password = $_SESSION[SESSION_LOGIN_USER_PASSWORD];
+
+    } elseif ($mode == 'stream' && paramExists('sr_check_user')) {
         $params = readConfigParams(array('sr_check_user',
                                          'sr_check_password'));
         $user     = $params['sr_check_user'];
@@ -684,9 +688,6 @@ function paramExists($param)
 /* Get if loginUser is super user */
 function isSuperUser($user_name)
 {
-    if (DoesPgpoolPidExist() && isset($_SESSION[SESSION_IS_SUPER_USER])) {
-        return $_SESSION[SESSION_IS_SUPER_USER];
-    }
     $conn = @pg_connect(conStrPgpool());
 
     if ($conn == FALSE) {
@@ -702,12 +703,13 @@ function isSuperUser($user_name)
     }
 
     $rr = pg_fetch_array($result);
-    $rtn = (isset($rr['usesuper']) && $rr['usesuper'] == 't');
+    $rtn = (isset($rr['usesuper']) && $rr['usesuper'] == 't') ? 'yes' : 'no';
 
     @pg_free_result($result);
     @pg_close($conn);
 
-     $_SESSION[SESSION_IS_SUPER_USER] = $rtn;
+    $_SESSION[SESSION_IS_SUPER_USER] = $rtn;
+
     return $rtn;
 }
 
